@@ -52,21 +52,28 @@ def anotherPage(timeout=DEFAULT_TIMEOUT):
             driver.switch_to.window(page)
 
 
-def keepOnePage():
+def clearAllPages():
     ary = driver.window_handles[:]
     for i in range(1, len(ary)):
         driver.switch_to.window(ary[i])
         driver.close()
     driver.switch_to.window(ary[0])
+    driver.get("data:,")
 
 
-def newTabAndCloseOthers():
+def keepCurrentPage():
     ary = driver.window_handles[:]
-    driver.switch_to.window("tab")
-    for xx in ary:
-        driver.switch_to.window(xx)
-        driver.close()
-    driver.switch_to.window(driver.window_handles[0])
+    if driver.current_window_handle in ary:
+        for page in ary:
+            if page != driver.current_window_handle:
+                driver.switch_to.window(page)
+                driver.close()
+    else:
+        for i in range(1, len(ary)):
+            driver.switch_to.window(ary[i])
+    driver.switch_to.window(
+        driver.window_handles[0]
+    )
 
 
 def getActionChains():
@@ -74,8 +81,6 @@ def getActionChains():
 
 
 def getRequests(condition=None):
-    if not _isWire:
-        raise Exception("不支持bs.getRequests操作，init需要指定参数isWire为True")
     if condition:
         ary = list(filter(condition, driver.requests))
     else:
@@ -83,24 +88,6 @@ def getRequests(condition=None):
     return ary
 
 
-def waitForRequest(url, timeout=None):
-    if not _isWire:
-        raise Exception("不支持bs.waitRequests操作，init需要指定参数isWire为True")
-    driver.wait_for_request(url, timeout)
-
-
-def setRequestsRule(*ruleList):
-    if not _isWire:
-        raise Exception("不支持bs.setRequestsRule操作，init需要指定参数isWire为True")
-    driver.scopes = ruleList
-
-
-def clearRequests(rule):
-    if not _isWire:
-        raise Exception("不支持bs.clearRequests操作，init需要指定参数isWire为True")
-    del driver.requests
-
-
 def _get(find, check, timeout, delay, interval, index):
     endTime = time.time() + timeout
     if delay:
@@ -211,3 +198,36 @@ def keyboardClearByCss(value, index=0, **parDict):
 def keyboardClearByLinkText(value, index=0, **parDict):
     item = getByLinkText(value, index=index, **parDict)[0]
     item.clear()
+
+
+# ------------------------------------------------------------
+
+
+def _checkIsWire():
+    if not _isWire:
+        raise Exception("不支持操作，init需要指定参数isWire为True")
+
+
+def waitForRequest(url, timeout=None):
+    _checkIsWire()
+    driver.wait_for_request(url, timeout)
+
+
+def setRequestsRule(*ruleList):
+    _checkIsWire()
+    driver.scopes = ruleList
+
+
+def setRequestsRuleDisabled():
+    _checkIsWire()
+    setRequestsRule("^$")
+
+
+def clearRequestsRule():
+    _checkIsWire()
+    setRequestsRule()
+
+
+def clearRequests(rule):
+    _checkIsWire()
+    del driver.requests
